********************************************************************************
** Objective:  Produce table A6: descriptive statistics comparing the PRISE database and the ENSETE database
** Author: 		Horacio Vera Cossio
** Date: 		12 Oct 2021
********************************************************************************

// *========================================================================================================================
// *      1 /  Compute descriptive statistics for ENSETE
// *========================================================================================================================	


// ENSETE 2013 //

preserve
*	use "$data/raw data/ENSETE_2013_17Septembre2014_nonmissing.dta", clear
*keep HID Household_ID strate m4a_impute m3 milieu hh1 hh2 education employ ap2b m1 lfpr m22 m15 ap3 autre popemp_old esna_old esa_old eina_old eia_old unemploy AGRMenageProprio e104 e114 e103 e102 e112 e108 e118 e117 e113 e109 e107 e105 e110 e111 e101 e106 e116 e119 possedeanimauxelevage pond 
use "$data/raw data/Baseline_raw_database.dta", replace
keep if ensete == 1 
keep ensete*
drop ensete
rename ensete_* *
* 1.1 Define pop. to be compared to PRISE: regions part of the RCT Tonkpi, Cavally, Guemon, and Bafing. Strata refers to districts not regions

	gen sample = (		strate == 14 | strate == 15 |						/// Montagnes district - includes Tonkpi, Cavally and Guemon. Rural and urban
							strate == 22 | strate == 23	)						// Waroba district - includes Bafing. Rural and urban

	gen eligible = (m4a_impute >=18 & m4a_impute <= 65 )
	
* 1.2 Construct variables

* Demographic variables 

	* Age
	gen age=m4a_impute
	label variable age "Age"
	
	* Sex
	recode m3 (1 = 0 "Male") (2 = 1 "Female") , g(gender)
	label variable gender "Gender"
	
	* Place of residence 
	gen urban = (milieu==1)			 											//all urban strata are uneven numbers
	label variable urban "Urban"
	
	* # of household members
	gen hhmember = 1
	egen hhmembers = total(hhmember) , by(hh1 hh2)	
	label variable hhmembers "Nb of household members"
	
* Education 

	* Has diploma
	recode education ///
		( 1 2 = 1 "No Diploma (primary education not completed)") ///
		( 3 = 2 "CEPE (primary education completed)") ///
		( 4 = 3 "BEPC (lower secondary education completed)") ///
		( 5 6 = 4 "BAC or more (upper secondary education completed)") ///
		( . = .) ///
		, gen(educational_attainment) 

	gen no_diploma = (education == 1 ) if !missing(education)
	label variable no_diploma "No diploma"
	
	* Has ever been to school
	
* Employment
	
	gen employed = employ == 1
	label variable employed "Employment (Has an activity of any type)"
	
	* Wage empl. , self-empl. agr, self-empl non-agr
	run "${dofile}/analysis/endline analysis/econ_act_cleaning.do"
	
	clonevar act_status = typeemp2
	replace act_status = 5 if branchsect15==1 & typeemp2==2 & popemp_old==1 
	replace act_status = 5 if branchsect15==2 & typeemp2==2 & popemp_old==1
	replace act_status = 2 if unemploy == 1
	replace act_status = 0 if inactivity_status == 1
	replace act_status = 1 if inactivity_status == 2

	label define typeemp 	0 "Inactive, at school " ///
							1 "Inactive, not at school " ///
							2 "Unemployed" ///
							3 "Wage employed (including informal)" ///
							4 "Self employed (non agricultural)" ///
							5 "Self-employed in agriculture" , replace

	label values act_status typeemp 

	gen self_empl = (act_status==4) if act_status>=3 & act_status<=5
	label var self_empl "Self empl. non-agr. (at least 1 activity)"

	gen self_empl_agr = (act_status==5) if act_status>=3 & act_status<=5
	label var self_empl_agr "Self empl. in agriculture (at least 1 activity)"
	
	gen wage_empl = (act_status==3) if act_status>=3 & act_status<=5
	label var wage_empl "Wage employed(at least 1 activity)"
	
	* Household has land
	
	recode AGRMenageProprio (0 = 0 "no land") (1 = 1 "owns land" ), g(own_land) 
	label variable own_land "HH owns land"
	

* Asset variables

	* Asset index
	
	* Household assets
	
	local assets_1 		has_charette ///
						has_brouette ///
						has_bicyclette ///
						has_velomoteur ///
						has_frigo ///
						has_congel /// has_clim /// 
						has_ventil ///
						has_cuisin ///
						has_ordi ///
						has_radio ///
						has_tv ///has_tel ///
						has_port ///
						has_voiture ///has_lecteur
						has_tracteur ///
						has_g_electr //
						
	local assets_2		`assets_1'	own_lvstock
						
	gen has_charette=(e104>0) if !missing(e104)
	replace has_charette=has_charette*100 
	gen has_brouette=(e114>0) if !missing(e114)
	replace has_brouette=has_brouette*100
	gen has_bicyclette=(e103>0) if !missing(e103)
	replace has_bicyclette=has_bicyclette*100
	gen has_velomoteur=(e102>0) if !missing(e102)
	replace has_velomoteur=has_velomoteur*100
	gen has_frigo=(e112>0) if !missing(e112)
	replace has_frigo=has_frigo*100
	gen has_congel=(e108>0) if !missing(e108)
	replace has_congel=has_congel*100
	gen has_clim=(e118>0) if !missing(e118)
	replace has_clim=has_clim*100
	gen has_ventil=(e117>0) if !missing(e117)
	replace has_ventil=has_ventil*100
	gen has_cuisin=(e113>0) if !missing(e113)
	replace has_cuisin=has_cuisin*100
	gen has_ordi=(e109>0) if !missing(e109)
	replace has_ordi=has_ordi*100
	gen has_radio=(e107>0) if !missing(e107)
	replace has_radio=has_radio*100
	gen has_tv=(e105>0) if !missing(e105)
	replace has_tv=has_tv*100
	gen has_tel=(e110>0) if !missing(e110)
	replace has_tel=has_tel*100
	gen has_port=(e111>0) if !missing(e111)
	replace has_port=has_port*100
	gen has_voiture=(e101>0) if !missing(e101)
	replace has_voiture=has_voiture*100
	gen has_lecteur=(e106>0) if !missing(e106)
	replace has_lecteur=has_lecteur*100
	gen has_tracteur=(e116) if !missing(e116)
	replace has_tracteur=has_tracteur*100
	gen has_g_electr=(e119) if !missing(e119)
	replace has_g_electr=has_g_electr*100
	

	label variable has_charette 	"Wagon"
	label variable has_brouette 	"Wheelbarrow"
	label variable has_bicyclette 	"Bicycle"
	label variable has_velomoteur 	"Motorcycle"
	label variable has_frigo 		"Refrigerator"
	label variable has_congel 		"Freezer"
	label variable has_clim 		"Air conditioner"
	label variable has_ventil 		"Fan"
	label variable has_cuisin 		"Stove"
	label variable has_ordi 		"Computer"
	label variable has_radio 		"Radio"
	label variable has_tv 			"Television"
	label variable has_tel 			"Telephone (land line)"
	label variable has_port 		"Mobile phone"
	label variable has_voiture 		"Car"
	label variable has_lecteur		"Dvd player"
	label variable has_tracteur		"Tractor"
	label variable has_g_electr		"Electricity generator"

	* Household owns livestock
	
	egen hh_lvstock = max(possedeanimauxelevage) , by(hh1 hh2)
	recode hh_lvstock (0 = 0 "no livestock") (1 = 1 "owns livestock" ) , g(own_lvstock) 
	label variable own_lvstock "HH owns livestock"
	
	* Asset index, without livestock
	
	pca `assets_1' [aw=pond] if sample==1 & eligible==1
	estimates store pcaENSETE_1														//keep estimates to predict score for THIMO obs

	predict asset_index
	sum asset_index [aw=pond] if sample==1 & eligible==1
	local mean_1=r(mean)
	local estdev_1=r(sd)

	replace asset_index=(asset_index-`mean_1')/`estdev_1'
	label variable asset_index "Asset Index (z-score)" 
	
	* Asset index, including livestock

	pca `assets_2' [aw=pond] if sample==1 & eligible==1
	estimates store pcaENSETE_2														//keep estimates to predict score for THIMO obs

	predict asset_index_lvstock
	sum asset_index_lvstock [aw=pond] if sample==1 & eligible==1
	local mean_2=r(mean)
	local estdev_2=r(sd)

	replace asset_index_lvstock=(asset_index_lvstock-`mean_2')/`estdev_2'
	label variable asset_index_lvstock "Asset Index, livestock included (z-score)" 

** last line to include sample size in the table
    count if sample==1 & eligible==1	
	gen sampled = r(N)
	label variable sampled		"Sample"
	
* 1.3 Run descriptive statistics


	estpost tabstat $Table_comp_ENSETE sampled [aw=pond] if sample==1 & eligible==1 , statistics(mean) columns(statistics)	
	eststo res_ENSETE_65


	
restore  

// *========================================================================================================================
// *      2 /  Compute descriptive statistics for PRISE
// *========================================================================================================================	

* 2.1 Define pop. to be compared to ENSETE
	
* 2.2 Construct variables


* Demographic variables 

	* Age
	gen age = b_age20_01_16
	label variable age "Age"

	* Sex
	cap drop gender
*	recode b_a1 (1 = 0 "Male") (2 = 1 "Female") , g(gender)
gen gender = b_a1
	label variable gender "Female"
	
	* Place of residence 
	gen urban = (b_milieu==0)			 											//all urban strata are uneven numbers
	label variable urban "Urban"
	
	* # of household members
	gen hhmembers = b_b4+1 	
	label variable hhmembers "Nb of household members"

	* # of kids - dropped for the moment since it is not clear how it was measured in PRISE
	*gen enfant = (m4a_impute<=15 & hhmember==1)									// According to ENSETE, people 14 years and older are part of the WAP
	*egen enfants = total(enfant) , by(hh1 hh2)

* Education 

	* Has diploma

	gen no_diploma = (b_a18 == 1 ) if !missing(b_a18)							// a18 is a5=never went to school and a7=no diploma
	label variable no_diploma "No diploma"
	
	* Has ever been to school
	
* Employment
	
		gen b_travail=(b_travail_da==1) 										// extracted from balance tables, uses same code			
		recode  b_travail (0=1) if b_dc_vide==0 | b_db_vide==0

	gen employed = b_travail
	label variable employed "Employment (Has an activity of any type)"
	
	* Wage empl. , self-empl. agr, self-empl non-agr
	
	gen act_status = b_db4  if employed==1 & b_db4<=7
	
	label values act_status typeemp 

	gen self_empl = (act_status==2 | act_status==3 ) if !missing(act_status)
	label var self_empl "Self empl. non-agr. (at least 1 activity)"

	gen self_empl_agr = (act_status==7 | act_status==4) if !missing(act_status)
	label var self_empl_agr "Self empl. in agriculture (at least 1 activity)"
	
	gen wage_empl = (act_status==1 | act_status==5 | act_status==6 ) if !missing(act_status)
	label var wage_empl "Wage employed(at least 1 activity)"
	
	* Household has land
	
	gen own_land = (b_c2>0) if !missing(b_c2) 
	label variable own_land "HH owns land"
	

* Asset variables

	* Asset index
	
	* Household assets
	
	gen has_charette=(C1_3>0) if !missing(C1_3)
	replace has_charette=has_charette*100 
	gen has_brouette=(C1_7>0) if !missing(C1_7)
	replace has_brouette=has_brouette*100
	gen has_bicyclette=(C1_8>0) if !missing(C1_8)
	replace has_bicyclette=has_bicyclette*100
	gen has_velomoteur=(C1_9>0) if !missing(C1_9)
	replace has_velomoteur=has_velomoteur*100
	gen has_frigo=(C1_14>0) if !missing(C1_14)
	replace has_frigo=has_frigo*100
	gen has_congel=(C1_15>0) if !missing(C1_15)
	replace has_congel=has_congel*100
	gen has_ventil=(C1_16>0) if !missing(C1_16)
	replace has_ventil=has_ventil*100
	gen has_cuisin=(C1_17>0) if !missing(C1_17)
	replace has_cuisin=has_cuisin*100
	gen has_ordi=(C1_18>0) if !missing(C1_18)
	replace has_ordi=has_ordi*100
	gen has_radio=(C1_19>0) if !missing(C1_19)
	replace has_radio=has_radio*100
	gen has_tv=(C1_20>0) if !missing(C1_20)
	replace has_tv=has_tv*100
	gen has_port=(C1_21>0) if !missing(C1_21)
	replace has_port=has_port*100
	gen has_voiture=(C1_13>0) if !missing(C1_13)
	replace has_voiture=has_voiture*100
	gen has_tracteur=(C1_12) if !missing(C1_12)
	replace has_tracteur=has_tracteur*100
	gen has_g_electr=(C1_23) if !missing(C1_23)
	replace has_g_electr=has_g_electr*100
	

	label variable has_charette 	"Wagon"
	label variable has_brouette 	"Wheelbarrow"
	label variable has_bicyclette 	"Bicycle"
	label variable has_velomoteur 	"Motorcycle"
	label variable has_frigo 		"Refrigerator"
	label variable has_congel 		"Freezer"
	label variable has_ventil 		"Fan"
	label variable has_cuisin 		"Stove"
	label variable has_ordi 		"Computer"
	label variable has_radio 		"Radio"
	label variable has_tv 			"Television"
	label variable has_port 		"Mobile phone"
	label variable has_voiture 		"Car"
	label variable has_tracteur		"Tractor"
	label variable has_g_electr		"Electricity generator"

	* Household owns livestock
	
	recode EeC (0 = 0 "no livestock") (1 = 1 "owns livestock" ) , g(own_lvstock) 
	label variable own_lvstock "HH owns livestock"
	
	estimates restore pcaENSETE_1														//keep estimates to predict score for THIMO obs

	predict asset_index
	replace asset_index=(asset_index-`mean_1')/`estdev_1'
	label variable asset_index "Asset Index (z-score)" 
	
	estimates restore pcaENSETE_2														//keep estimates to predict score for THIMO obs

	predict asset_index_lvstock
	replace asset_index_lvstock=(asset_index_lvstock-`mean_2')/`estdev_2'
	label variable asset_index_lvstock "Asset Index livestock included (z-score)" 
	

** last line to include sample size in the table
    count if attrit_i_e==0 & treat_common_main==0	
	gen sampled = r(N)
	label variable sampled		"Sample"

* 2.3 Run descriptive statistics

	estpost tabstat $Table_comp_ENSETE sampled if attrit_i_e==0 & treat_common_main==0 [weight= sampling_w_main] , statistics(mean) columns(statistics)	
	eststo res_PRISE


// *========================================================================================================================
// *      3 /  Put together the table A7
// *========================================================================================================================	

esttab res_ENSETE_65 res_PRISE using "$output/table_A7.tex" , ///
		mtitles(	"\makecell{People 18-65 \\ in intervened \\ districts \\ (2013-2014)}" ///
					"\makecell{PRISE \\ participants \\ (2015-2016)}") ///
					cells(mean(fmt(3))) label noobs collabels(none) booktabs replace

